@@ -1,5 +1,5 @@
 package App::Oozie::Deploy;
-$App::Oozie::Deploy::VERSION = '0.011';
+$App::Oozie::Deploy::VERSION = '0.012';
 use 5.014;
 use strict;
 use warnings;
@@ -464,7 +464,9 @@ sub __collect_internal_conf {
         ( $keep ? ' You have decided to keep it after completion' : '' )
     );
 
-    $config->{hdfs_dest} = $self->destination_path( $config->{workflowsBaseDir} );
+    $config->{workflowsBaseDir} //= $self->oozie_basepath;
+    $config->{clusterName}      //= $self->cluster_name;
+    $config->{hdfs_dest}        //= $self->destination_path( $config->{workflowsBaseDir} );
 
     # if YARN, use a different property. the oozie syntax doesn't change (still
     # uses the jobtracker property)
@@ -1231,7 +1233,7 @@ App::Oozie::Deploy
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
